Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(213)

Unified Diff: milo/api/config/project.proto

Issue 2982183002: Milo: Store console defs as their own entities (Closed)
Patch Set: Rebase fixes and Working Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | milo/api/config/project.pb.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: milo/api/config/project.proto
diff --git a/milo/api/config/project.proto b/milo/api/config/project.proto
index 163feff35a34ce2a784aa1dffaeb84b7ba7b5e2a..aa8ad6a3e447f425e8ef14187c35aacc5a9b998f 100644
--- a/milo/api/config/project.proto
+++ b/milo/api/config/project.proto
@@ -28,8 +28,9 @@ message Console {
// RepoURL is the URL of the git repository to display as the rows of the console.
string RepoURL = 3;
- // Branch is the branch to pull commits from when displaying the console.
- string Branch = 4;
+ // Ref is the ref to pull commits from when displaying the console.
+ // Eg. refs/heads/master
+ string Ref = 4;
// ManifestName is the name of the manifest the waterfall looks at.
// By convention, Manifest Names can be:
« no previous file with comments | « no previous file | milo/api/config/project.pb.go » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698